@@ -42,9 +42,9 @@ struct _NetDeviceSimplePrivate
 G_DEFINE_TYPE (NetDeviceSimple, net_device_simple, NET_TYPE_DEVICE)
 
 static GtkWidget *
-device_simple_proxy_add_to_notebook (NetObject *object,
-                                     GtkNotebook *notebook,
-                                     GtkSizeGroup *heading_size_group)
+device_simple_proxy_add_to_stack (NetObject    *object,
+                                  GtkStack     *stack,
+                                  GtkSizeGroup *heading_size_group)
 {
         GtkWidget *widget;
         NetDeviceSimple *device_simple = NET_DEVICE_SIMPLE (object);
@@ -56,7 +56,7 @@ device_simple_proxy_add_to_notebook (NetObject *object,
 
         widget = GTK_WIDGET (gtk_builder_get_object (device_simple->priv->builder,
                                                      "vbox6"));
-        gtk_notebook_append_page (notebook, widget, NULL);
+        gtk_stack_add_named (stack, widget, net_object_get_id (object));
         return widget;
 }
 
@@ -85,7 +85,7 @@ static void
 nm_device_simple_refresh_ui (NetDeviceSimple *device_simple)
 {
         NetDeviceSimplePrivate *priv = device_simple->priv;
-        char *hwaddr;
+        const char *hwaddr;
         GtkWidget *widget;
         char *speed = NULL;
         NMDevice *nm_device;
@@ -119,11 +119,8 @@ nm_device_simple_refresh_ui (NetDeviceSimple *device_simple)
         panel_set_device_status (priv->builder, "label_status", nm_device, speed);
 
         /* device MAC */
-        g_object_get (G_OBJECT (nm_device),
-                      "hw-address", &hwaddr,
-                      NULL);
+        hwaddr = nm_device_get_hw_address (nm_device);
         panel_set_device_widget_details (priv->builder, "mac", hwaddr);
-        g_free (hwaddr);
 
         /* set IP entries */
         panel_set_device_widgets (priv->builder, nm_device);
@@ -222,7 +219,7 @@ net_device_simple_class_init (NetDeviceSimpleClass *klass)
 
         object_class->finalize = net_device_simple_finalize;
         object_class->constructed = net_device_simple_constructed;
-        parent_class->add_to_notebook = device_simple_proxy_add_to_notebook;
+        parent_class->add_to_stack = device_simple_proxy_add_to_stack;
         parent_class->refresh = device_simple_refresh;
         simple_class->get_speed = device_simple_get_speed;
 
