@@ -21,6 +21,7 @@
 #include "cc-search-panel.h"
 #include "cc-search-locations-dialog.h"
 #include "cc-search-resources.h"
+#include "shell/list-box-helper.h"
 
 #include <gio/gdesktopappinfo.h>
 #include <glib/gi18n.h>
@@ -405,6 +406,7 @@ switch_settings_mapping_get_generic (GValue *value,
         }
     }
 
+  g_free (apps);
   g_value_set_boolean (value, !!default_enabled != !!found);
 
   return TRUE;
@@ -519,7 +521,10 @@ search_panel_add_one_provider (CcSearchPanel *self,
     }
 
   if (!g_key_file_has_group (keyfile, SHELL_PROVIDER_GROUP))
-    goto out;
+    {
+      g_debug ("Shell search provider group missing from '%s', ignoring", path);
+      goto out;
+    }
 
   desktop_id = g_key_file_get_string (keyfile, SHELL_PROVIDER_GROUP,
                                       "DesktopId", &error);
@@ -532,11 +537,16 @@ search_panel_add_one_provider (CcSearchPanel *self,
     }
 
   app_info = G_APP_INFO (g_desktop_app_info_new (desktop_id));
-  g_free (desktop_id);
 
   if (app_info == NULL)
-    goto out;
+    {
+      g_debug ("Could not find application with desktop ID '%s' referenced in '%s', ignoring",
+               desktop_id, path);
+      g_free (desktop_id);
+      goto out;
+    }
 
+  g_free (desktop_id);
   default_disabled = g_key_file_get_boolean (keyfile, SHELL_PROVIDER_GROUP,
                                              "DefaultDisabled", NULL);
   search_panel_add_one_app_info (self, app_info, !default_disabled);
@@ -741,7 +751,7 @@ cc_search_panel_init (CcSearchPanel *self)
 {
   GError    *error;
   GtkWidget *widget;
-  GtkWidget *scrolled_window;
+  GtkWidget *frame;
   guint res;
 
   self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, CC_TYPE_SEARCH_PANEL, CcSearchPanelPrivate);
@@ -762,11 +772,12 @@ cc_search_panel_init (CcSearchPanel *self)
       return;
     }
 
-  scrolled_window = WID ("scrolled_window");
+  frame = WID ("search_frame");
   widget = GTK_WIDGET (gtk_list_box_new ());
   gtk_list_box_set_sort_func (GTK_LIST_BOX (widget),
                               (GtkListBoxSortFunc)list_sort_func, self, NULL);
-  gtk_container_add (GTK_CONTAINER (scrolled_window), widget);
+  gtk_list_box_set_header_func (GTK_LIST_BOX (widget), cc_list_box_update_header_func, NULL, NULL);
+  gtk_container_add (GTK_CONTAINER (frame), widget);
   self->priv->list_box = widget;
   gtk_widget_show (widget);
 
